@@ -1,8 +1,12 @@
 from .data_clean import data_clean
+from .feature_importance import feature_imp
+from .graph_prep import graphprep #, clean_text seems to live in graphprep?
+from .graph_viz import graphviz
 from .hand_labelled_features import hand_label
 from .lift import lift
 from .model import model
 from .recode_categorical import recode_categorical
 from .sent_analysis import sent_analysis
+from .shap_visualization import shap_visuals
 from .spacy_functions import nlp_xtrct_pos, nlp_xtrct_dep, nlp_xtrct_elab, spacyanalysis
 from .topic_model_features import clean_text, topic_features
